#include <iostream>
#include <vector>

int maksimalan_zbir(const std::vector<int> &niz)
{
    // Na pocetku je max suma segmenata jednaka sumi segmenta [0, 0], tj prvom elementu niza
    int max = niz[0];
    // Ovde cemo cuvati vrednost sume segmenta koji trenutno razmatramo, tj sumu segmenta [i, j] za fiksirano i i klizno j (menja se stalno za fiksirano i)
    int trenutni_zbir;
    int n = niz.size();

    // Najnaivnije resenje, prolazak kroz sve segmente koji postoje linearno
    // Imamo ukupno O(n^2) segmenata, i kada prodjemo kroz svaki od njih linearno, slozenost je O(n^3)
    // for (int i = 0; i < n - 1; i++) {
    //     for (int j = i + 1; j < n; j++) {
    //         trenutni_zbir = 0;
    //         for (int k = i; k <= j; k++) {
    //             trenutni_zbir += niz[k];
    //         }
    //         if (trenutni_zbir > max) {
    //             max = trenutni_zbir;
    //         }
    //     }
    // }

    // Malo bolje resenje
    // Fiksiramo levi kraj
    for (int i = 0; i < n; i++) {
        // Zbir segmenata koji pocinju na poziciji i je 0 na pocetku
        trenutni_zbir = 0;
        // Prolazimo kroz sve segmente, ovo nam predstavlja desni kraj
        for (int j = i; j < n; j++) {
            // Zbir racunamo na osnovu prethodnog. Znamo zbir elemenata [i, j - 1] i na taj zbir dodajemo i j-ti element i dobijamo sumu
            // segmenta [i, j]
            trenutni_zbir += niz[j];
            // Ako se desi da je zbir segmenta [i, j] veci od dosadasnjeg maksimuma, samo azuriramo max
            if (trenutni_zbir > max) {
                max = trenutni_zbir;
            }
        }
    }

    // Na kraju vracamo globalni maksimum
    return max;
}

int main ()
{
    std::vector<int> niz = {1, -3, 2, 1, -1};

    std::cout << maksimalan_zbir(niz) << "\n";

    return 0;
}